@@ -1,3 +1,7 @@
+import numpy as np
+
+import pandas as pd
+
 #获取ppm
 def get_ppm(pfm_ ):
     ppm = []
