@@ -1,3 +1,6 @@
+import numpy as np
+
+import pandas as pd
 #获得一组定长的ppm
 def get_ppm_L(ppm,L_ = 8):
     ppm_L = []
