@@ -1,3 +1,7 @@
+import numpy as np
+
+import pandas as pd
+
 #获得一组定长的ppm，每个值-0.5，均值近0
 def get_ppm_rp25_L(ppm,L_ = 8):
     ppm_L = []
